"use client";

import React from 'react';
import { motion } from 'framer-motion';

interface CastBasicInfoProps {
  profileImage: string;
  name: string;
  rating?: number;  // Optional rating (popularity)
  dateOfBirth: string;
  placeOfBirth: string;
  biography: string;  // Add biography
}

const CastBasicInfo: React.FC<CastBasicInfoProps> = ({ profileImage, name, rating, dateOfBirth, placeOfBirth, biography }) => {
  return (
    <div
      className="relative flex flex-col md:flex-row items-center p-6 rounded-lg shadow-lg text-white"
      style={{
        backgroundImage: `url(${profileImage})`,
        backgroundSize: 'cover',
        backgroundPosition: 'center center',
        height: '65vh',
        borderRadius: '15px', // Rounded corners for the component
      }}
    >
      {/* Red Overlay */}
      <div className="absolute inset-0 bg-red-600 opacity-60 rounded-lg"></div>

      {/* Profile Image */}
      <motion.div
        className="relative z-10 w-40 h-60 md:w-48 md:h-72 flex-shrink-0 rounded-lg shadow-lg object-cover md:absolute md:left-10"
        initial={{ opacity: 0, x: -100 }}
        animate={{ opacity: 1, x: 0 }}
        transition={{ duration: 0.8, ease: 'easeOut' }}
      >
        <img
          src={profileImage}
          alt={name}
          className="w-full h-full rounded-lg object-cover"
        />
      </motion.div>

      {/* Info Section */}
      <motion.div
        className="relative z-10 flex-1 md:ml-64 text-center md:text-left mt-4 md:mt-0"
        initial={{ opacity: 0, x: 100 }}
        animate={{ opacity: 1, x: 0 }}
        transition={{ duration: 0.8, ease: 'easeOut' }}
      >
        <h2 className="text-2xl md:text-4xl font-bold mb-4">{name}</h2>
        
        {rating !== undefined && (
          <div className="flex items-center justify-center md:justify-start mb-4">
            <span className="text-yellow-400 text-lg mr-2">{rating.toFixed(1)}</span>
            <div className="flex">
              {Array.from({ length: 5 }, (_, index) => (
                <svg
                  key={index}
                  className={`w-5 h-5 ${index < Math.round(rating / 2) ? 'text-yellow-400' : 'text-gray-400'}`}
                  fill="currentColor"
                  viewBox="0 0 24 24"
                >
                  <path d="M12 .587l3.668 7.451 8.218 1.191-5.93 5.784 1.4 8.165L12 18.897l-7.356 3.868 1.4-8.165-5.93-5.784 8.218-1.191z" />
                </svg>
              ))}
            </div>
          </div>
        )}

        <p className="text-sm md:text-lg mb-2">
          <span className="font-semibold">Date of Birth: </span>{dateOfBirth}
        </p>
        <p className="text-sm md:text-lg">
          <span className="font-semibold">Place of Birth: </span>{placeOfBirth}
        </p>
        <p className="text-sm md:text-lg mt-4 line-clamp-3">
          <span className="font-semibold">Biography: </span>{biography}
        </p>
      </motion.div>
    </div>
  );
};

export default CastBasicInfo;
